Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
MakeSquareRoot.PrimeFieldinclude Ff_sig.BASEexception Not_in_field of Bytes.tval order : Z.tThe order of the finite field
val check_bytes : Bytes.t -> boolcheck_bytes bs returns true if bs is a correct byte representation of a field element
val zero : tThe neutral element for the addition
val one : tThe neutral element for the multiplication
val is_zero : t -> boolis_zero x returns true if x is the neutral element for the addition
val is_one : t -> boolis_one x returns true if x is the neutral element for the multiplication
val random : ?state:Random.State.t -> unit -> tUse carefully! random () returns a random element of the field. A state for the PRNG can be given to initialize the PRNG in the requested state. If no state is given, no initialisation is performed
val non_null_random : ?state:Random.State.t -> unit -> tUse carefully! non_null_random () returns a non null random element of the field. A state for the PRNG can be given to initialize the PRNG in the requested state. If no state is given, no initialisation is performed
negate x returns -x mod order. Equivalently, negate x returns the unique y such that x + y mod order = 0
From a predefined bytes representation, construct a value t. It is not required that to_bytes of_bytes_exn t = t. Raise Not_in_field if the bytes do not represent an element in the field.
From a predefined bytes representation, construct a value t. It is not required that to_bytes (Option.get (of_bytes_opt t)) = t. By default, little endian encoding is used and the given element is modulo the prime order
val factor_power_of_two : int * Z.tReturns s, q such that order - 1 = 2^s * q
val of_string : string -> tCreate a value t from a predefined string representation. It is not required that to_string of_string t = t. By default, decimal representation of the number is used, modulo the order of the field
val to_string : t -> stringString representation of a value t. It is not required that to_string of_string t = t. By default, decimal representation of the number is used
of_z x builds an element t from the Zarith element x. mod order is applied if x >= order
to_z x builds a Zarith element, using the decimal representation. Arithmetic on the result can be done using the modular functions on integers
Returns the Legendre symbol of the parameter. Note it does not work for p = 2
val is_quadratic_residue : t -> boolis_quadratic_residue x returns true if x is a quadratic residue i.e. if there exists n such that n^2 mod p = 1